==> nextcloud-app-spreed-5.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/da.js <==
OC.L10N.register(
    "spreed",
    {
    "Validate SSL certificate" : "Validt SSL certifikat",
    "Delete server" : "Slet server",
    "Add new server" : "Tilføj ny server",
    "Saved" : "Gemt",
    "Shared secret" : "Delt hemmelighed",
    "TURN server shared secret" : "TURN server delte hemmelighed",
    "UDP and TCP" : "UDP og TCP",
    "UDP only" : "kun UDP",
    "TCP only" : "kun TCP",
    "TURN server protocols" : "TURN server protokoller ",
    "Participants" : "Deltagere",
    "Chat" : "Chat",
    "Talk" : "Snak",
    "Copy" : "Kopiér",
    "Copied!" : "Kopieret!",
    "Not supported!" : "Ikke understøttet",
    "Press ⌘-C to copy." : "Tryk ⌘-C for at kopiere.",
    "Press Ctrl-C to copy." : "Tryk Ctrl-C for at kopiere.",
    "Please enter the password for this call" : "Indtast venligst password for dette opkald",
    "Password required" : "Password påkrævet",
    "Password" : "Password",
    "Cancel" : "Annullér",
    "Submit" : "Indsend",
    "Leave call" : "Forlad opkald",
    "Join call" : "Deltag i opkaldet",
    "Share link" : "Del link",
    "Change password" : "Skift password",
    "Set password" : "Sæt password",
    "Name" : "Navn",
    "Rename" : "Omdøb",
    "You" : "Dig",
    "No messages yet, start the conversation!" : "Ingen beskeder endnu, start samtalen!",
    "Send" : "Send",
    "Guest" : "Gæst",
    "[Unknown user name]" : "[Ukendt brugernavn] ",
    "Error occurred while sending message" : "Der opstod fejl under indsendelse af besked",
    "Edit" : "Rediger",
    "No other people in this call" : "Ingen andre deltager i dette opkald",
    "Waiting for {participantName} to join the call …" : "Venter på {participantName} tilslutter sig opkaldet ...",
    "Waiting for others to join the call …" : "Venter på andre tilslutter sig opkaldet ...",
    "Share this link to invite others!" : "Del dette link for at invitere andre!",
    "WebRTC is not supported in your browser :-/" : "WebRTC er ikke undertøttet i din browser :-/",
    "Please use a different browser like Firefox or Chrome" : "Benyt venligst en anden browser f.eks. Firefox eller Chrome",
    "Waiting for camera and microphone permissions" : "Venter på kamera og mikrofon tilladelser",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "For at give bruge denne app skal du give din browser adgang til dit kamera og mikrofon.",
    "Disable video" : "Deaktiver video",
    "Share screen" : "Del skærm",
    "Show your screen" : "Vis din skærm",
    "Stop screensharing" : "Stop skærmdeling",
    "Screensharing is not supported by your browser." : "Skærmdeling er ikke understøttet af din browser.",
    "Screensharing requires the page to be loaded through HTTPS." : "Skærmdeling kræver at siden bliver vist gennem HTTPS.",
    "Screensharing options" : "Skærmdeling indstillinger",
    "Sharing your screen only works with Firefox version 52 or newer." : "Skærmdeling virker kun med Firefox version 52 eller nyere.",
    "Screensharing extension is required to share your screen." : "En skærmdeling udvidelse er påkrævet for at dele din skærm.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Brug venligst en anden browser som Firefox og Chrome for at dele din skærm.",
    "An error occurred while starting screensharing." : "Der opstod en fejl da du prøvede at dele skærm.",
    "Enable screensharing" : "Slå skærmdeling til",
    "moderator" : "modeator",
    "Demote from moderator" : "Degrader fra moderator",
    "Promote to moderator" : "Forfrem til moderator",
    "Remove participant" : "Fjern deltager",
    "Close" : "Luk",
    "Show screen" : "Vis skærm",
    "Access to microphone & camera is only possible with HTTPS" : "Adgang til mikrofon og kamera er kun tilgængeligt over HTTPS",
    "Access to microphone & camera was denied" : "Ingen adgang til mikrofon og kamera",
    "WebRTC is not supported in your browser" : "WebRTC er ikke undertøttet i din browser",
    "Error while accessing microphone & camera" : "Der opstod en fejl da vi prøvede at få adgang til din mikrofon og kamera",
    "{participantName}'s screen" : "{participantName}s skærm",
    "Guest's screen" : "Gæsts skærm",
    "Your screen" : "Din skærm",
    "(Duration %s)" : "(Varighed %s)",
    "You attended a call with {user1}" : "Du deltog i et opkald med {user1}",
    "_%n guest_::_%n guests_" : ["%n gæst","%n gæster"],
    "You attended a call with {user1} and {user2}" : "Du deltog i et opkald med {user1} og {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Du deltog i et opkald med {user1}, {user2} og {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Du deltog i et opkald med {user1}, {user2}, {user3} og {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Du deltog i et opkald med {user1}, {user2}, {user3}, {user4} og {user5}",
    "_%n other_::_%n others_" : ["%n andre","%n andre"],
    "{actor} invited you to {call}" : "{actor} inviterede dig til {call}",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Du var inviteret til et <strong>snakke</strong> rum eller fik et <strong>opkald</strong>",
    "_%n other guest_::_%n other guests_" : ["%n anden gæst","%n andre gæster"],
    ", " : ", ",
    "{user} wants to talk with you" : "{user} vil gerne snakke med dig",
    "A group call has started in {call}" : "Et gruppeopkald er started i {call}",
    "A group call has started" : "Et gruppeopkald er startet",
    "This call is password-protected" : "Dette opkald er password beskyttet ",
    "The password is wrong. Try again." : "Passwordet er forkert. Prøv igen.",
    "Signaling server" : "Signalerer server",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "En ekstern signaleringsserver kan eventuelt bruges i større installationer. Efterlad tom for at bruge intern signaleringsserver.",
    "STUN servers" : "STUN servere",
    "A STUN server is used to determine the public IP address of participants behind a router." : "En STUN server bliver brugt til at bestemme den offentlige IP adresse for deltagerne bagved en router.",
    "TURN server" : "TURN server",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN serveren bliver brugt til at proxy trafikken fra deltagerne bagved en firewall.",
    "(group)" : "(gruppe)",
    "and you" : "og dif",
    "… %s" : "… %s",
    "%s …" : "%s …",
    "… %s …" : "… %s …"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-spreed-5.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/da.js <==
OC.L10N.register(
    "spreed",
    {
    "Validate SSL certificate" : "Godkend SSL certifikat",
    "Delete server" : "Slet server",
    "Add new server" : "Tilføj ny server",
    "Saved" : "Gemt",
    "Shared secret" : "Delt hemmelighed",
    "TURN server shared secret" : "TURN server delte hemmelighed",
    "UDP and TCP" : "UDP og TCP",
    "UDP only" : "kun UDP",
    "TCP only" : "kun TCP",
    "TURN server protocols" : "TURN server protokoller ",
    "New public conversation" : "Ny offentlig samtale",
    "New group conversation" : "Ny gruppesamtale",
    "New conversation …" : "Ny samtale …",
    "Participants" : "Deltagere",
    "Chat" : "Chat",
    "Talk" : "Snak",
    "Fullscreen (f)" : "Fuldskærm (f)",
    "Copy" : "Kopiér",
    "Copied!" : "Kopieret!",
    "Not supported!" : "Ikke understøttet",
    "Press ⌘-C to copy." : "Tryk ⌘-C for at kopiere.",
    "Press Ctrl-C to copy." : "Tryk Ctrl-C for at kopiere.",
    "Start a conversation" : "Start en samtale",
    "Share" : "Del",
    "Please enter the password for this call" : "Indtast venligst password for dette opkald",
    "Password required" : "Password påkrævet",
    "Password" : "Password",
    "Cancel" : "Annullér",
    "Submit" : "Indsend",
    "Leave call" : "Forlad opkald",
    "Join call" : "Deltag i opkaldet",
    "Start call" : "Start opkald",
    "Share link" : "Del link",
    "Change password" : "Skift password",
    "Set password" : "Sæt password",
    "Go to file" : "Gå til fil",
    "Name" : "Navn",
    "Conversation name" : "Samtalenavn",
    "Rename" : "Omdøb",
    "Copy link" : "Kopier link",
    "Conversation with {name}" : "Samtale med {name}",
    "Link copied!" : "Link kopieret!",
    "You" : "Dig",
    "No messages yet, start the conversation!" : "Ingen beskeder endnu, start samtalen!",
    "New message …" : "Ny besked …",
    "Send" : "Send",
    "Guest" : "Gæst",
    "[Unknown user name]" : "[Ukendt brugernavn] ",
    "Today" : "I dag",
    "Yesterday" : "I går",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Error occurred while sending message" : "Der opstod fejl under indsendelse af besked",
    "Edit" : "Rediger",
    "Join a conversation or start a new one" : "Deltag i en samtale eller start en ny",
    "No other people in this call" : "Ingen andre deltager i dette opkald",
    "Waiting for {participantName} to join the call …" : "Venter på {participantName} tilslutter sig opkaldet ...",
    "Waiting for others to join the call …" : "Venter på andre tilslutter sig opkaldet ...",
    "Share this link to invite others!" : "Del dette link for at invitere andre!",
    "WebRTC is not supported in your browser :-/" : "WebRTC er ikke undertøttet i din browser :-/",
    "Please use a different browser like Firefox or Chrome" : "Benyt venligst en anden browser f.eks. Firefox eller Chrome",
    "Waiting for camera and microphone permissions" : "Venter på kamera og mikrofon tilladelser",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "For at give bruge denne app skal du give din browser adgang til dit kamera og mikrofon.",
    "Mute audio" : "Slå lyden fra",
    "Disable video" : "Deaktiver video",
    "Share screen" : "Del skærm",
    "Share whole screen" : "Del hele skærmen",
    "Share a single window" : "Del et vindue",
    "Show your screen" : "Vis din skærm",
    "Stop screensharing" : "Stop skærmdeling",
    "Unmute audio (m)" : "Slå lyden til (m)",
    "Mute audio (m)" : "Slå lyden fra (m)",
    "No audio" : "Ingen lyd",
    "Enable video (v)" : "Slå video til (v)",
    "Disable video (v)" : "Slå video fra (v)",
    "No Camera" : "Intet kamera",
    "Screensharing is not supported by your browser." : "Skærmdeling er ikke understøttet af din browser.",
    "Screensharing requires the page to be loaded through HTTPS." : "Skærmdeling kræver at siden bliver vist gennem HTTPS.",
    "Screensharing options" : "Skærmdeling indstillinger",
    "Sharing your screen only works with Firefox version 52 or newer." : "Skærmdeling virker kun med Firefox version 52 eller nyere.",
    "Screensharing extension is required to share your screen." : "En skærmdeling udvidelse er påkrævet for at dele din skærm.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Brug venligst en anden browser som Firefox og Chrome for at dele din skærm.",
    "An error occurred while starting screensharing." : "Der opstod en fejl da du prøvede at dele skærm.",
    "Enable screensharing" : "Slå skærmdeling til",
    "moderator" : "moderator",
    "Demote from moderator" : "Degrader fra moderator",
    "Promote to moderator" : "Forfrem til moderator",
    "Remove participant" : "Fjern deltager",
    "Add to favorites" : "Føj til favoritter",
    "Leave conversation" : "Forlad samtale",
    "Delete conversation" : "Slet samtale",
    "Close" : "Luk",
    "Show screen" : "Vis skærm",
    "Access to microphone & camera is only possible with HTTPS" : "Adgang til mikrofon og kamera er kun tilgængeligt over HTTPS",
    "Access to microphone & camera was denied" : "Ingen adgang til mikrofon og kamera",
    "WebRTC is not supported in your browser" : "WebRTC er ikke undertøttet i din browser",
    "Error while accessing microphone & camera" : "Der opstod en fejl da vi prøvede at få adgang til din mikrofon og kamera",
    "{participantName}'s screen" : "{participantName}s skærm",
    "Guest's screen" : "Gæsts skærm",
    "Your screen" : "Din skærm",
    "a conversation" : "en samtale",
    "(Duration %s)" : "(Varighed %s)",
    "You attended a call with {user1}" : "Du deltog i et opkald med {user1}",
    "_%n guest_::_%n guests_" : ["%n gæst","%n gæster"],
    "You attended a call with {user1} and {user2}" : "Du deltog i et opkald med {user1} og {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Du deltog i et opkald med {user1}, {user2} og {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Du deltog i et opkald med {user1}, {user2}, {user3} og {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Du deltog i et opkald med {user1}, {user2}, {user3}, {user4} og {user5}",
    "_%n other_::_%n others_" : ["%n andre","%n andre"],
    "{actor} invited you to {call}" : "{actor} inviterede dig til {call}",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Du var inviteret til et <strong>snakke</strong> rum eller fik et <strong>opkald</strong>",
    "_%n other guest_::_%n other guests_" : ["%n anden gæst","%n andre gæster"],
    ", " : ", ",
    "{user} wants to talk with you" : "{user} vil gerne snakke med dig",
    "A group call has started in {call}" : "Et gruppeopkald er startet i {call}",
    "A group call has started" : "Et gruppeopkald er startet",
    "This call is password-protected" : "Dette opkald er password beskyttet ",
    "The password is wrong. Try again." : "Passwordet er forkert. Prøv igen.",
    "Signaling server" : "Signalerer server",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "En ekstern signaleringsserver kan eventuelt bruges i større installationer. Efterlad tom for at bruge intern signaleringsserver.",
    "STUN servers" : "STUN servere",
    "A STUN server is used to determine the public IP address of participants behind a router." : "En STUN server bliver brugt til at bestemme den offentlige IP adresse for deltagerne bagved en router.",
    "TURN server" : "TURN server",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN serveren bliver brugt til at proxy trafikken fra deltagerne bagved en firewall.",
    "(group)" : "(gruppe)",
    "and you" : "og dif",
    "… %s" : "… %s",
    "%s …" : "%s …",
    "… %s …" : "… %s …"
},
"nplurals=2; plural=(n != 1);");
